@@ -13,7 +13,7 @@ use open qw(:std :utf8);
 
 use Ufal::UDPipe;
 
-@ARGV >= 3 or die "Usage: $0 input_format output_format model_file\n";
+@ARGV >= 3 or die "Usage: $0 input_format(tokenize|conllu|horizontal|vertical) output_format(conllu) model_file\n";
 my $input = shift @ARGV;
 my $output = shift @ARGV;
 my $model_file = shift @ARGV;
@@ -26,20 +26,13 @@ print STDERR "done\n";
 my $pipeline = Ufal::UDPipe::Pipeline->new($model, $input, $Ufal::UDPipe::Pipeline::DEFAULT, $Ufal::UDPipe::Pipeline::DEFAULT, $output);
 my $error = Ufal::UDPipe::ProcessingError->new();
 
-for (my $not_eof = 1; $not_eof; ) {
-  my $text = '';
-
-  # Read block
-  while (1) {
-    my $line = <>;
-    last unless ($not_eof = defined $line);
-    $text .= $line;
-    chomp($line);
-    last unless length $line;
-  }
-
-  # Process data
-  my $processed = $pipeline->process($text, $error);
-  $error->occurred() and die "An error occurred in run_udpipe: " . $error->{message};
-  print $processed;
+# Read whole input
+my $text = '';
+for (my $line; $line = <>; ) {
+  $text .= $line;
 }
+
+# Process data
+my $processed = $pipeline->process($text, $error);
+$error->occurred() and die "An error occurred in run_udpipe: " . $error->{message};
+print $processed;
