@@ -76,9 +76,10 @@ class multiword_token : public token {
  public:
   // form and misc are inherited from token
   int id_first, id_last;
+  std::string feats; // can contain only Typo=Yes
 
   multiword_token(int id_first = -1, int id_last = -1, string_piece form = string_piece(), string_piece misc = string_piece())
-      : token(form, misc), id_first(id_first), id_last(id_last) {}
+      : token(form, misc), id_first(id_first), id_last(id_last), feats() {}
 };
 
 class empty_node {
@@ -159,6 +160,7 @@ class output_format {
   // Static factory methods
   static output_format* new_output_format(const std::string& name);
   static output_format* new_conllu_output_format(const std::string& options = std::string());
+  static output_format* new_epe_output_format(const std::string& options = std::string());
   static output_format* new_matxin_output_format(const std::string& options = std::string());
   static output_format* new_horizontal_output_format(const std::string& options = std::string());
   static output_format* new_plaintext_output_format(const std::string& options = std::string());
